# cronverter

A Python package for converting cron expressions between different formats.

Look inside the `docs/` folder to read more about it and how to use it.

## supported formats

### to unix

- [x] from quartz

### from unix

- [ ] to quartz

